@@ -1,6 +1,6 @@
 module Fog
-  module Storage
-    class AzureRM
+  module AzureRM
+    class Storage
       # This class provides the actual implemention for service calls.
       class Real
         # Get a public container url from Azure storage container
@@ -24,8 +24,8 @@ module Fog
       # This class provides the mock implementation for unit tests.
       class Mock
         def get_container_url(_container_name, options = {})
-          url = 'https://sa.blob.core.windows.net/test_container?comp=list&restype=container'
-          url.gsub!('https:', 'http:') if options[:scheme] == 'http'
+          url = 'https://mockaccount.blob.core.windows.net/test_container?comp=list&restype=container'
+          url.sub!('https:', 'http:') if options[:scheme] == 'http'
           url
         end
       end
