@@ -1,6 +1,6 @@
 module Fog
-  module Storage
-    class AzureRM
+  module AzureRM
+    class Storage
       # This class provides the actual implemention for service calls.
       class Real
         # Generate a pre-signed URL for create an object in an Azure blob storage
@@ -22,7 +22,7 @@ module Fog
             expiry: expires.utc.iso8601,
             protocol: 'https'
           }
-          token = @signature_client.generate_service_sas_token(relative_path, params)
+          token = signature_client(expires).generate_service_sas_token(relative_path, params)
           uri = @blob_client.generate_uri(relative_path, {}, { encode: true })
           "#{uri}?#{token}"
         end
@@ -31,7 +31,7 @@ module Fog
       # This class provides the mock implementation for unit tests.
       class Mock
         def put_blob_https_url(*)
-          'https://sa.blob.core.windows.net/test_container/test_blob?token'
+          'https://mockaccount.blob.core.windows.net/test_container/test_blob?token'
         end
       end
     end
