@@ -99,11 +99,6 @@ module Fog
           "#{protocol}://#{storage_account_name}.#{domain}"
         end
 
-        def current_time
-          time = Time.now.to_f.to_s
-          time.split(/\W+/).join
-        end
-
         # Parse storage blob/container to a hash
         def parse_storage_object(object)
           data = {}
