@@ -3,7 +3,7 @@ require File.expand_path '../../test_helper', __dir__
 # Test class for Storage Container Model
 class TestFile < Minitest::Test # rubocop:disable Metrics/ClassLength
   def setup
-    @service = Fog::Storage::AzureRM.new(storage_account_credentials)
+    @service = Fog::AzureRM::Storage.new(storage_account_credentials)
     @directory = directory(@service)
     @file = file(@service)
     @raw_cloud_blob = storage_blob
@@ -171,7 +171,7 @@ class TestFile < Minitest::Test # rubocop:disable Metrics/ClassLength
       @service.stub :copy_blob, [copy_id, copy_status] do
         @service.stub :wait_blob_copy_operation_to_finish, true do
           target_file = @file.copy('target_container', 'target_blob')
-          assert_instance_of Fog::Storage::AzureRM::File, target_file
+          assert_instance_of Fog::AzureRM::Storage::File, target_file
         end
       end
     end
@@ -290,8 +290,20 @@ class TestFile < Minitest::Test # rubocop:disable Metrics/ClassLength
   end
 
   def test_url_method_with_response_content_disposition
-    @file.collection.stub :get_url, @blob_https_url, { content_disposition: 'attachment' } do
-      assert @file.url(Time.now + 3600, { query: { 'response-content-disposition' => 'attachment' } }), @blob_https_url
+    fake = Minitest::Mock.new
+    expiry = Time.now + 3600
+    fake.expect :call, nil, [@file.key, expiry, { content_disposition: 'attachment', content_type: nil }]
+    @file.collection.stub(:get_url, fake) do
+      @file.url(expiry, { query: { 'response-content-disposition' => 'attachment' } })
+    end
+  end
+
+  def test_url_method_with_response_content_type
+    fake = Minitest::Mock.new
+    expiry = Time.now + 3600
+    fake.expect :call, nil, [@file.key, expiry, { content_disposition: nil, content_type: 'image/png' }]
+    @file.collection.stub(:get_url, fake) do
+      @file.url(expiry, { query: { 'response-content-type' => 'image/png' } })
     end
   end
 
