@@ -5,22 +5,20 @@ class TestGetBlobHttpUrl < Minitest::Test
   # This class posesses the test cases for the requests of Blob service.
   def setup
     Fog.mock!
-    @mock_service = Fog::Storage::AzureRM.new(storage_account_credentials)
+    @mock_service = Fog::AzureRM::Storage.new(storage_account_credentials)
     Fog.unmock!
 
-    @service = Fog::Storage::AzureRM.new(storage_account_credentials)
+    @service = Fog::AzureRM::Storage.new(storage_account_credentials)
     @blob_client = @service.instance_variable_get(:@blob_client)
-    @signature_client = @service.instance_variable_get(:@signature_client)
+    @signature_client = @service.send(:signature_client, Minitest::Mock.new)
 
     @url = ApiStub::Requests::Storage::File.blob_https_url.gsub('https:', 'http:')
     @token = ApiStub::Requests::Storage::File.blob_url_token
   end
 
   def test_get_blob_http_url_success
-    @blob_client.stub :generate_uri, @url do
-      @signature_client.stub :generate_service_sas_token, @token do
-        assert_equal "#{@url}?#{@token}", @service.get_blob_http_url('test_container', 'test_blob', Time.now.utc + 3600)
-      end
+    @signature_client.stub :generate_service_sas_token, @token do
+      assert_equal "#{@url}?#{@token}", @service.get_blob_http_url('test_container', 'test_blob', Time.now.utc + 3600)
     end
   end
 
@@ -29,7 +27,7 @@ class TestGetBlobHttpUrl < Minitest::Test
     mock_generate_service_token = Minitest::Mock.new
     url_params = { content_disposition: 'attachment' }
 
-    mock_generate_uri.expect(:call, @url, ['test_container/test_blob', {}, { encode: true }])
+    mock_generate_uri.expect(:call, URI.parse(@url), ['test_container/test_blob', {}, { encode: true }])
     mock_generate_service_token.expect(:call, @token) do |_relative_path, params|
       params[:service] == 'b' &&
         params[:resource] == 'b' &&
@@ -49,7 +47,7 @@ class TestGetBlobHttpUrl < Minitest::Test
     mock_generate_uri = Minitest::Mock.new
     mock_generate_service_token = Minitest::Mock.new
 
-    mock_generate_uri.expect(:call, @url, ['.test0/..test1/...test2', {}, { encode: true }])
+    mock_generate_uri.expect(:call, URI.parse(@url), ['.test0/..test1/...test2', {}, { encode: true }])
     mock_generate_service_token.expect(:call, @token) do |relative_path, _|
       relative_path == '.test0/..test1/...test2'
     end
@@ -61,6 +59,12 @@ class TestGetBlobHttpUrl < Minitest::Test
     end
   end
 
+  def test_get_url_https_in_container_and_blob_names
+    uri = URI.parse(@service.get_blob_http_url('https://container', 'https://blob', Time.now.utc + 3600))
+    assert_equal 'http', uri.scheme
+    assert_equal '/https://container/https://blob', CGI.unescape(uri.path)
+  end
+
   def test_get_blob_http_url_mock
     assert_equal "#{@url}?#{@token}", @mock_service.get_blob_http_url('test_container', 'test_blob', Time.now.utc + 3600)
   end
